@@ -3,9 +3,10 @@
 
 class Scene;
 class Viewpoint;
-class GLBitmapFont;
+class GLFont;
 
 #include "math.h"
+#include "opengl.hpp"
 
 class RenderContext
 {
@@ -23,14 +24,17 @@ public:
   , gl2psActive(0)
   { }
   Scene* scene;
-  Rect   rect;
+  Rect2   rect;
   // RectSize size;
   Viewpoint* viewpoint;
-  GLBitmapFont* font;
+  GLFont* font;
   double time;
   double lastTime;
   double deltaTime;
-  float getDistance(const Vertex& v);
+  float getDistance(const Vertex& v) const;
+  GLdouble modelview[16];
+  GLdouble projection[16];
+  GLint viewport[4];
   Vec4 Zrow;
   Vec4 Wrow;
   int gl2psActive;
