@@ -4,7 +4,7 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: gui.hpp 616 2007-11-29 15:18:21Z dmurdoch $
+// $Id: gui.hpp 666 2008-04-17 13:44:58Z dmurdoch $
 // ---------------------------------------------------------------------------
 #include <cstring>
 #include "types.h"
@@ -58,6 +58,7 @@ public:
   inline WindowImpl(Window* in_window)
   : window(in_window)
   { 
+    fonts.resize(1);
   }
   inline  void unbind() { window = 0; }
   virtual void setTitle(const char* title) = 0;
@@ -76,8 +77,13 @@ public:
   virtual void swap(void) = 0;
   virtual void captureMouse(View* captureView) = 0;
   virtual void releaseMouse(void) = 0;
+  virtual GLFont* getFont(const char* family, int style, double cex, 
+                          bool useFreeType) = 0;
+  void getFonts(FontArray& outfonts, int nfonts, char** family, int* style, double* cex, 
+                bool useFreeType);
+
   // OpenGL support (FIXME: remove)
-  GLBitmapFont font;
+  FontArray fonts;
 protected:
   Window*      window;
 };
@@ -197,6 +203,8 @@ public:
   void bringToTop(int stay);
   void setWindowRect(int left, int top, int right, int bottom);
   void getWindowRect(int *left, int *top, int *right, int *bottom);
+  void getFonts(FontArray& outfonts, int nfonts, char** family, int* style, double* cex,
+                bool useFreeType);
 
 // data:
   View* child;
